@@ -8,6 +8,11 @@
 #' monikers to load (must be a dictionary in
 #' \code{\link[SemNetDictionaries]{dictionaries}})
 #' 
+#' @param vector Boolean.
+#' Should output be a vector? If \code{FALSE},
+#' then output is a list.
+#' Defaults to \code{TRUE}
+#' 
 #' @return Returns a vector of unique words that have been combined
 #' and alphabetized from the specified monikers
 #' 
@@ -22,7 +27,7 @@
 #' 
 #' @export
 #Load moniker Function
-load.monikers <- function (moniker)
+load.monikers <- function (moniker, vector = TRUE)
 {
     #set in case of corpus being used
     if(length(moniker)>10)
@@ -62,7 +67,9 @@ load.monikers <- function (moniker)
     }
     
     #combine into vector and alphabetize
-    full.misn <- sort(unlist(misn.list))
+    if(vector)
+    {full.misn <- sort(unlist(misn.list))
+    }else{full.misn <- unlist(misn.list, recursive = FALSE)}
     
     return(full.misn)
 }
